@@ -7,6 +7,8 @@ from pathlib import Path
 py = sys.argv[1]
 if py.startswith("brew@"):
     py = py[len("brew@") :]
+if py.startswith("graalpy-"):
+    py = "graalpy"
 env = f"TOXENV={py}"
 if len(sys.argv) > 2:  # noqa: PLR2004
     env += f"\nTOX_BASEPYTHON={sys.argv[2]}"
