@@ -19,7 +19,7 @@ CURRENT = PythonInfo.current_system()
 @pytest.fixture(scope="session")
 def zipapp_build_env(tmp_path_factory):
     create_env_path = None
-    if CURRENT.implementation != "PyPy":
+    if CURRENT.implementation not in {"PyPy", "GraalVM"}:
         exe = CURRENT.executable  # guaranteed to contain a recent enough pip (tox.ini)
     else:
         create_env_path = tmp_path_factory.mktemp("zipapp-create-env")
@@ -112,6 +112,7 @@ def test_zipapp_help(call_zipapp, capsys):
     assert not err
 
 
+@pytest.mark.slow
 @pytest.mark.parametrize("seeder", ["app-data", "pip"])
 def test_zipapp_create(call_zipapp, seeder):
     call_zipapp("--seeder", seeder)
