@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from shutil import which
 
 from virtualenv.activation import NushellActivator
@@ -6,7 +8,7 @@ from virtualenv.info import IS_WIN
 
 def test_nushell(activation_tester_class, activation_tester):
     class Nushell(activation_tester_class):
-        def __init__(self, session):
+        def __init__(self, session) -> None:
             cmd = which("nu")
             if cmd is None and IS_WIN:
                 cmd = "c:\\program files\\nu\\bin\\nu.exe"
@@ -17,7 +19,7 @@ def test_nushell(activation_tester_class, activation_tester):
             self.unix_line_ending = not IS_WIN
 
         def print_prompt(self):
-            return r"$env.VIRTUAL_PROMPT"
+            return r"print $env.VIRTUAL_PREFIX"
 
         def activate_call(self, script):
             # Commands are called without quotes in Nushell
