@@ -26,7 +26,9 @@ def test_current_as_json():
     result = CURRENT._to_json()  # noqa: SLF001
     parsed = json.loads(result)
     a, b, c, d, e = sys.version_info
+    f = sysconfig.get_config_var("Py_GIL_DISABLED") == 1
     assert parsed["version_info"] == {"major": a, "minor": b, "micro": c, "releaselevel": d, "serial": e}
+    assert parsed["free_threaded"] is f
 
 
 def test_bad_exe_py_info_raise(tmp_path, session_app_data):
@@ -59,7 +61,7 @@ def test_bad_exe_py_info_no_raise(tmp_path, caplog, capsys, session_app_data):
     itertools.chain(
         [sys.executable],
         [
-            f"{impl}{'.'.join(str(i) for i in ver)}{arch}"
+            f"{impl}{'.'.join(str(i) for i in ver)}{'t' if CURRENT.free_threaded else ''}{arch}"
             for impl, ver, arch in itertools.product(
                 (
                     [CURRENT.implementation]
@@ -90,6 +92,14 @@ def test_satisfy_not_arch():
     assert matches is False
 
 
+def test_satisfy_not_threaded():
+    parsed_spec = PythonSpec.from_string_spec(
+        f"{CURRENT.implementation}{CURRENT.version_info.major}{'' if CURRENT.free_threaded else 't'}",
+    )
+    matches = CURRENT.satisfies(parsed_spec, True)
+    assert matches is False
+
+
 def _generate_not_match_current_interpreter_version():
     result = []
     for i in range(3):
@@ -309,7 +319,7 @@ def test_discover_exe_on_path_non_spec_name_not_match(mocker):
 
 @pytest.mark.skipif(IS_PYPY, reason="setuptools distutils patching does not work")
 def test_py_info_setuptools():
-    from setuptools.dist import Distribution
+    from setuptools.dist import Distribution  # noqa: PLC0415
 
     assert Distribution
     PythonInfo()
@@ -406,11 +416,11 @@ def test_fallback_existent_system_executable(mocker):
     mocker.patch.object(sys, "executable", current.executable)
 
     # ensure it falls back to an alternate binary name that exists
-    current._fast_get_system_executable()  # noqa: SLF001
-    assert os.path.basename(current.system_executable) in [
+    system_executable = current._fast_get_system_executable()  # noqa: SLF001
+    assert os.path.basename(system_executable) in [
         f"python{v}" for v in (current.version_info.major, f"{current.version_info.major}.{current.version_info.minor}")
     ]
-    assert os.path.exists(current.system_executable)
+    assert os.path.exists(system_executable)
 
 
 @pytest.mark.skipif(sys.version_info[:2] != (3, 10), reason="3.10 specific")
